# HVPS

These are the nodejs bindings for the [hvps](https://github.com/lobis/hvps) python package.

In order for this npm package to work, the python package must be installed.

The python package can be installed via:

```
python -m pip install hvps
```

Note: you should install the same version of the python package as the version of the nodejs package.
You can follow the instructions from the error message if you get a version mismatch error.

## Usage

TODO
